==> openshift-model-operatorhub-5.1.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface OperatorGroupStatusFluent<A extends OperatorGroupStatusFluent<A>> extends Fluent<A> {


    public String getLastUpdated();
    public A withLastUpdated(String lastUpdated);
    public Boolean hasLastUpdated();
    public A withNewLastUpdated(String arg1);
    public A withNewLastUpdated(StringBuilder arg1);
    public A withNewLastUpdated(StringBuffer arg1);
    public A addToNamespaces(int index,String item);
    public A setToNamespaces(int index,String item);
    public A addToNamespaces(String... items);
    public A addAllToNamespaces(Collection<String> items);
    public A removeFromNamespaces(String... items);
    public A removeAllFromNamespaces(Collection<String> items);
    public List<String> getNamespaces();
    public String getNamespace(int index);
    public String getFirstNamespace();
    public String getLastNamespace();
    public String getMatchingNamespace(Predicate<String> predicate);
    public Boolean hasMatchingNamespace(Predicate<String> predicate);
    public A withNamespaces(List<String> namespaces);
    public A withNamespaces(String... namespaces);
    public Boolean hasNamespaces();
    public A addNewNamespace(String arg1);
    public A addNewNamespace(StringBuilder arg1);
    public A addNewNamespace(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildServiceAccountRef instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getServiceAccountRef();
    public ObjectReference buildServiceAccountRef();
    public A withServiceAccountRef(ObjectReference serviceAccountRef);
    public Boolean hasServiceAccountRef();
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> withNewServiceAccountRef();
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> withNewServiceAccountRefLike(ObjectReference item);
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> editServiceAccountRef();
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> editOrNewServiceAccountRef();
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> editOrNewServiceAccountRefLike(ObjectReference item);
    public interface ServiceAccountRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<OperatorGroupStatusFluent.ServiceAccountRefNested<N>> {

            public N and();
            public N endServiceAccountRef();    }


}

==> openshift-model-operatorhub-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface OperatorGroupStatusFluent<A extends OperatorGroupStatusFluent<A>> extends Fluent<A> {


    public String getLastUpdated();
    public A withLastUpdated(String lastUpdated);
    public Boolean hasLastUpdated();
    public A withNewLastUpdated(StringBuilder arg1);
    public A withNewLastUpdated(int[] arg1,int arg2,int arg3);
    public A withNewLastUpdated(char[] arg1);
    public A withNewLastUpdated(StringBuffer arg1);
    public A withNewLastUpdated(byte[] arg1,int arg2);
    public A withNewLastUpdated(byte[] arg1);
    public A withNewLastUpdated(char[] arg1,int arg2,int arg3);
    public A withNewLastUpdated(byte[] arg1,int arg2,int arg3);
    public A withNewLastUpdated(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLastUpdated(String arg1);
    public A addToNamespaces(int index,String item);
    public A setToNamespaces(int index,String item);
    public A addToNamespaces(String... items);
    public A addAllToNamespaces(Collection<String> items);
    public A removeFromNamespaces(String... items);
    public A removeAllFromNamespaces(Collection<String> items);
    public List<String> getNamespaces();
    public String getNamespace(int index);
    public String getFirstNamespace();
    public String getLastNamespace();
    public String getMatchingNamespace(Predicate<String> predicate);
    public Boolean hasMatchingNamespace(Predicate<String> predicate);
    public A withNamespaces(List<String> namespaces);
    public A withNamespaces(String... namespaces);
    public Boolean hasNamespaces();
    public A addNewNamespace(StringBuilder arg1);
    public A addNewNamespace(int[] arg1,int arg2,int arg3);
    public A addNewNamespace(char[] arg1);
    public A addNewNamespace(StringBuffer arg1);
    public A addNewNamespace(byte[] arg1,int arg2);
    public A addNewNamespace(byte[] arg1);
    public A addNewNamespace(char[] arg1,int arg2,int arg3);
    public A addNewNamespace(byte[] arg1,int arg2,int arg3);
    public A addNewNamespace(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewNamespace(String arg1);
    
/**
 * This method has been deprecated, please use method buildServiceAccountRef instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getServiceAccountRef();
    public ObjectReference buildServiceAccountRef();
    public A withServiceAccountRef(ObjectReference serviceAccountRef);
    public Boolean hasServiceAccountRef();
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> withNewServiceAccountRef();
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> withNewServiceAccountRefLike(ObjectReference item);
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> editServiceAccountRef();
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> editOrNewServiceAccountRef();
    public OperatorGroupStatusFluent.ServiceAccountRefNested<A> editOrNewServiceAccountRefLike(ObjectReference item);
    public interface ServiceAccountRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<OperatorGroupStatusFluent.ServiceAccountRefNested<N>> {

            public N and();
            public N endServiceAccountRef();    }


}
